[Résolu] Tuyau sur spirale

Bonjour,

Mon Topsolid peine sur l’application d’un tuyau sur un profil spirale spacial. Est ce normale docteur ?

Sur base d’un projet vide. Pas de problème pour la spirale spatiale (D=800, pas 400, angle début 0°, angle fin 2160°). Par contre appliquer un tuyau (D=33, épaisseur 2,6) sur ce profil semble extrêmement difficile (10 minutes de travail plus qu’intensif de ma machine relativement performante)…

Avez vous le même problème ?

Peux-tu nous joindre ton fichier, comme çà on verra tout de suite si on a le même problème ?

Voici mon fichier avec les 2 fonctions :

  1. Spirale spatiale (rapide, pas de problème)
  2. Tuyau sur profil spirale (hyper lent…)

Le paquet est très lourd pour seulement 2 fonctions (6,95Mo).
http://www.forthomme.be/public/TestSpirale.TopPkg

Comment améliorer la vitesse de la fonction tuyau (en création et édition) et alléger le paquet ?

Merci pour votre aide.

effectivement c’est lent, que çà soit pour générer le tuyau à partir de la spirale filaire ou pour modifier le tuyau que tu as déjà créé.
c’est pas 10 minutes chez moi mais 1 à 2 minutes avant que ça réponde et que TopSolid redonne la main, c’est pas normal…

Effectivement, c’est plutot entre 1 et 2 minutes.
Hier, c’était 10 minutes car mon pc indexait son contenu en même temps(Windows Search).

6.9 est bien plus rapide. Sans oublier qu’il n’y a pas de prévisualisation dans cette version.

Y a t il une solution vis à vis de la grosseur du paquet ? 6,95Mo me semble énorme pour une seule pièce reprenant 2 fonctions (1 esquisse + 1 forme)

là, il faut qu’on attende que quelqu’un de chez Missler ai fait le test…

Hello,

On regarde ça :sunglasses: de plus près et on vous tient informé.

Cdt

Bonjour,

C’est un problème connu qui existait déjà en V6, et une demande d’évolution va être enregistrée pour traiter le problème.

Cdt

:open_mouth: j’ai pas essayé en version7, mais en v6, avec les données de FortyForty c’est 1/10 de seconde (en fait c’est pas vraiment quantifiable car quasi instantané) et 600ko de données…Tant mieux qu’il soit corrigé d’ici là…
jehronimo

Bonjour,

J’ai signalé ce pb au Développement qui va traiter ce problème.
Merci de votre aide !

Cdt